Feeders
=======

.. automodule:: stonesoup.feeder
    :no-members:

.. automodule:: stonesoup.feeder.base
    :show-inheritance:

Filter
------

.. automodule:: stonesoup.feeder.filter
    :show-inheritance:

Geo
---

.. automodule:: stonesoup.feeder.geo
    :show-inheritance:

Time Based
----------

.. automodule:: stonesoup.feeder.time
    :show-inheritance:

